==> qtjambi-serialport-debuginfo-macos-5.15.18.jar: sources/QtJambiSerialPort/QSerialPort_shell.h <==
#ifndef QSERIALPORT_SHELL_H
#define QSERIALPORT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtSerialPort/qserialport.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtSerialPort/qserialportinfo.h>
#include <QtJambi/RegistryAPI>


class QSerialPort_shell : public QSerialPort, public QtJambiShellInterface
{
public:
    QSerialPort_shell(QObject* parent0 = nullptr);
    QSerialPort_shell(const QSerialPortInfo& info0, QObject* parent1 = nullptr);
    QSerialPort_shell(const QString& name0, QObject* parent1 = nullptr);
    ~QSerialPort_shell() override;

    bool atEnd() const override;
    qint64 bytesAvailable() const override;
    qint64 bytesToWrite() const override;
    bool canReadLine() const override;
    void childEvent(QChildEvent* event0) override;
    void close() override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    bool isSequential() const override;
    bool open(QIODevice::OpenMode mode0) override;
    qint64 pos() const override;
    qint64 readData(char* data0, qint64 maxSize1) override;
    qint64 readLineData(char* data0, qint64 maxSize1) override;
    bool reset() override;
    bool seek(qint64 pos0) override;
    qint64 size() const override;
    void timerEvent(QTimerEvent* event0) override;
    bool waitForBytesWritten(int msecs0) override;
    bool waitForReadyRead(int msecs0) override;
    qint64 writeData(const char* data0, qint64 maxSize1) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QSerialPort_access : public QSerialPort
{
    jboolean __qt_atEnd(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jlong __qt_bytesAvailable(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jlong __qt_bytesToWrite(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_canReadLine(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_close(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_isSequential(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_open_QIODevice_OpenMode(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint mode0);
    jint __qt_readData_char_ptr_qint64(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject data0);
    jint __qt_readLineData_char_ptr_qint64(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject data0);
    jboolean __qt_waitForBytesWritten_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint msecs0);
    jboolean __qt_waitForReadyRead_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint msecs0);
    jint __qt_writeData_const_char_ptr_qint64(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject data0);
};

#endif // QSERIALPORT_SHELL_H

==> qtjambi-serialport-debuginfo-macos-5.15.20.jar: sources/QtJambiSerialPort/QSerialPort_shell.h <==
#ifndef QSERIALPORT_SHELL_H
#define QSERIALPORT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtSerialPort/qserialport.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtSerialPort/qserialportinfo.h>
#include <QtJambi/RegistryAPI>


class QSerialPort_shell : public QSerialPort, public QtJambiShellInterface
{
public:
    QSerialPort_shell(QObject* parent0 = nullptr);
    QSerialPort_shell(const QSerialPortInfo& info0, QObject* parent1 = nullptr);
    QSerialPort_shell(const QString& name0, QObject* parent1 = nullptr);
    ~QSerialPort_shell() override;

    bool atEnd() const override;
    qint64 bytesAvailable() const override;
    qint64 bytesToWrite() const override;
    bool canReadLine() const override;
    void childEvent(QChildEvent* event0) override;
    void close() override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    bool isSequential() const override;
    bool open(QIODevice::OpenMode mode0) override;
    qint64 pos() const override;
    qint64 readData(char* data0, qint64 maxSize1) override;
    qint64 readLineData(char* data0, qint64 maxSize1) override;
    bool reset() override;
    bool seek(qint64 pos0) override;
    qint64 size() const override;
    void timerEvent(QTimerEvent* event0) override;
    bool waitForBytesWritten(int msecs0) override;
    bool waitForReadyRead(int msecs0) override;
    qint64 writeData(const char* data0, qint64 maxSize1) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QSerialPort_access : public QSerialPort
{
    jboolean __qt_atEnd_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jlong __qt_bytesAvailable_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jlong __qt_bytesToWrite_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_canReadLine_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_close(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_isSequential_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_open_QIODevice_OpenMode(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint mode0);
    jint __qt_readData_char_ptr_qint64(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject data0);
    jint __qt_readLineData_char_ptr_qint64(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject data0);
    jboolean __qt_waitForBytesWritten_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint msecs0);
    jboolean __qt_waitForReadyRead_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint msecs0);
    jint __qt_writeData_const_char_ptr_qint64(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject data0);
};

#endif // QSERIALPORT_SHELL_H
